@@ -30,6 +30,10 @@ class IndexExcludeAllOf(BaseObject):
             8-Jun-2022
             craigtrim@gmail.com
             *   https://github.com/grafflr/deepnlu/issues/45
+        Updated:
+            30-Nov-2022
+            craigtrim@gmail.com
+            *   add sorting to key for values
 
         :param mapping:
         """
@@ -42,9 +46,16 @@ class IndexExcludeAllOf(BaseObject):
 
         for k in self._mapping:
             for mapping in self._mapping[k]:
-                if 'exclude_all_of' in mapping:
-                    values = '-'.join(set(mapping['exclude_all_of']))
-                    d[values] = k
+
+                if 'exclude_all_of' not in mapping:
+                    continue
+
+                if not len(mapping['exclude_all_of']):
+                    continue
+
+                values = set(mapping['exclude_all_of'])
+                values = '-'.join(sorted(values, reverse=False))
+                d[values] = mapping['exclude_all_of']
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
