@@ -42,9 +42,15 @@ class IndexExcludeOneOf(BaseObject):
 
         for k in self._mapping:
             for mapping in self._mapping[k]:
-                if 'exclude_one_of' in mapping:
-                    for marker_name in mapping['exclude_one_of']:
-                        d[marker_name].append(k)
+
+                if 'exclude_one_of' not in mapping:
+                    continue
+
+                if not len(mapping['exclude_one_of']):
+                    continue
+
+                for marker_name in mapping['exclude_one_of']:
+                    d[marker_name].append(k)
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
