@@ -46,8 +46,8 @@ class IndexStartsWith(BaseObject):
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
-                "Generated Index: StartsWith",
-                f"\tTotal Rows: {len(d)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Generated Index: StartsWith',
+                f'\tTotal Rows: {len(d)}',
+                f'\tTotal Time: {str(sw)}']))
 
         return dict(d)
