@@ -1,3 +1,3 @@
-from .predict_mapping import PredictMapping
+from .filter_mapping import FilterMapping
 from .select_mapping import SelectMapping
 from .read_mapping import ReadMapping
